baas_host = "https://api.catalyze.io"
paas_host = "https://paas-api.catalyze.io"
username = None
password = None

dashboard_url = "https://dashboard.catalyze.io"

api_key = "32a384f5-5d11-4214-812e-b35ced9af4d7"

behavior = {}

version = "1.2.3"
